// JavaScript Document
// Created by Fabian Toepper, October 14, 2013.
// based  on D3JS -- D3JS.org

// Must reference <script src="http://d3js.org/d3.v3.min.js" charset="utf-8"></script> 
// or <script src="js/d3.v3.min.js" charset="utf-8"></script> 


/////////// Configure Chart here
    var height_chart = 220;   // define height of chart in px
    var width_chart = 420;    // define width of chart in px                           
    var number_elements = 50; // define the number of elements in the chart
    
    var axisspace_x = 20;
    var axisspace_y_top = 20;
    var axisspace_y_bottom = 20;
    var axisspace_x_left = 20;
    var max_y = 4;
    var number_ticks = 8;
    
    var transition_speed = 100;
    //////////////////////////////////    
    
    var data = d3.range(number_elements);
    var t = 0; // variable to keep global data index
    
    /// calculate graph scale
    var y = d3.scale.linear()
               .domain([0, max_y])
               .rangeRound([height_chart - axisspace_y_top - axisspace_y_bottom, "0"]);         
    
    // Calculate bar width / circle radius
    var width_bar =  Math.floor((width_chart - axisspace_x) / (number_elements));
                                        
    // Append html SVG container
    var chart = d3.select("body")
                  .append("svg")
                  .attr("width", width_chart)
                  .attr("height", height_chart)
                  .attr("class", "chart")
                  .attr("id", "mychart")
                  .append("g")
                  .attr("transform", "translate("+axisspace_x+","+axisspace_y_top+")");

    // Add tick lines
    chart.selectAll("line")
      .data(y.ticks(number_ticks))
      .enter().append("line")
      .attr("y1", y)
      .attr("y2", y)
      .attr("x1", 0)
      .attr("x2", width_chart-axisspace_x)
      .style("stroke", "#ccc");
    
    function draw_circles()
    {      
        // Join data with circle elements
        var rect = chart.selectAll("circle")
                        .data(data, function(d) { return d.time; });
        
        // enter new circle elements for new data                                             
        rect.enter().insert("circle", "line.axis")                          
             .attr("r", 0.1)              
             .attr("cx", function(d, i) { return (i+1)* width_bar; })
             .attr("cy", function(d) { return y(d.value)})
             .attr("stroke", "#0000ff")
             .style("stroke-width", "1")
             .attr("fill", "#dddddd"); 
        
        // update existing circle elements according to data    
        rect.transition()
             .duration(transition_speed)
             .attr("cx", function(d, i) { return i*width_bar ; })
             .attr("r", width_bar);                                                  
                                                                        
        // remove circle elements not linked to data any more
        rect.exit()
            .transition()
            .duration(transition_speed)
            .attr("r", "0")
            .remove();
    }
    
         
    // Add text for tick lines
    chart.selectAll(".rule")
       .data(y.ticks(number_ticks))
       .enter().append("text")
       .attr("class", "rule")
       .attr("y", y)
       .attr("dy", 3)
       .attr("x", 0)       
       .attr("dx", -20)
       .attr("text-anchor", "middle")
       .attr("font-family", "Arial")
       .attr("font-size", "10")
       .text(String);         
    
    // Add left hand side y-axis line   
    chart.append("line")
       .attr("y1", 0)
       .attr("y2", height_chart - axisspace_y_top - axisspace_y_bottom)
       .attr("class", "axis")
       .style("stroke", "#000000")       
       .style("stroke-width", "2");
    
    // Add bottom x-axis line   
    chart.append("line")
       .attr("y1", height_chart - axisspace_y_bottom - axisspace_y_top)
       .attr("y2", height_chart - axisspace_y_bottom - axisspace_y_top)
       .attr("x1", 0)
       .attr("x2", width_chart - axisspace_x_left)
       .attr("class", "axis")
       .style("stroke", "#000000")
       .style("stroke-width", "2");   